package com.gree.mall.manager.logic;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gree.mall.manager.bean.admin.AdminUserCom;
import com.gree.mall.manager.bean.letter.LeDepartmentVO;
import com.gree.mall.manager.bean.letter.LeLetterVO;
import com.gree.mall.manager.bean.letter.LeProjectVO;
import com.gree.mall.manager.bean.letter.LeUserDepartmentVO;
import com.gree.mall.manager.bean.policy.PolicyOrderVO;
import com.gree.mall.manager.commonmapper.LetterMapper;
import com.gree.mall.manager.exception.RemoteServiceException;
import com.gree.mall.manager.logic.common.CommonLogic;
import com.gree.mall.manager.plus.entity.*;
import com.gree.mall.manager.plus.service.*;
import com.gree.mall.manager.zfire.bean.ZfireParamBean;
import com.gree.mall.manager.zfire.util.FieldUtils;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.List;

@Service
public class LetterLogic {

    @Autowired
    LetterMapper letterMapper;

    @Autowired
    CommonLogic commonLogic;

    @Autowired
    LeDepartmentService leDepartmentService;

    @Autowired
    LeUserDepartmentService leUserDepartmentService;

    @Autowired
    LeConfigService leConfigService;

    @Autowired
    AdminUserService adminUserService;

    @Autowired
    AdminWebsitService adminWebsitService;

    @Autowired
    LeProjectService leProjectService;

    @Autowired
    LeLetterService leLetterService;


    public IPage<LeDepartmentVO> list(Page page, ZfireParamBean zfireParam) {
        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, LeDepartmentVO.class, adminUser);

        IPage<LeDepartmentVO> leDepartmentVOIPage = letterMapper.list(page, zfireParam, adminCompanyIds);
        return leDepartmentVOIPage;
    }

    public LeDepartment detail(String id) {

        LeDepartment leDepartment = leDepartmentService.getById(id);
        return leDepartment;

    }

    public void add(LeDepartment leDepartment) {

        if (leDepartmentService.lambdaQuery().eq(LeDepartment::getDapartment,leDepartment.getDapartment()).count() > 0)
            throw new RemoteServiceException("重复科室名称");

        leDepartment.insert();
    }

    public void update(LeDepartment leDepartment) {
        if (leDepartmentService.lambdaQuery().eq(LeDepartment::getDapartment,leDepartment.getDapartment())
                .ne(LeDepartment::getId,leDepartment.getId()).count() > 0)
            throw new RemoteServiceException("重复科室名称");

        leDepartment.updateById();
    }

    public void del(String id) {

        leDepartmentService.removeById(id);
    }

    public IPage<LeUserDepartmentVO> listUser(Page page, ZfireParamBean zfireParam) {

        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, LeUserDepartmentVO.class, adminUser);

        IPage<LeUserDepartmentVO> leUserDepartmentVOIPage = letterMapper.listUser(page, zfireParam, adminCompanyIds);
        return leUserDepartmentVOIPage;
    }

    public LeUserDepartment detailUser(String id) {
        LeUserDepartment leUserDepartment = leUserDepartmentService.getById(id);
        return leUserDepartment;
    }

    public void addUser(LeUserDepartment leUserDepartment) {

        if (leUserDepartmentService.lambdaQuery().eq(LeUserDepartment::getAdminUserId,leUserDepartment.getAdminUserId())
                .eq(LeUserDepartment::getWebsitId,leUserDepartment.getWebsitId())
                .eq(LeUserDepartment::getDapartmentId,leUserDepartment.getDapartmentId()).count() > 0) {
            throw new RemoteServiceException("该账号设置过科室");
        }

        leUserDepartment.insert();

    }

    public void updateUser(LeUserDepartment leUserDepartment) {

        if (leUserDepartmentService.lambdaQuery().eq(LeUserDepartment::getAdminUserId,leUserDepartment.getAdminUserId())
                .eq(LeUserDepartment::getWebsitId,leUserDepartment.getWebsitId())
                .eq(LeUserDepartment::getDapartmentId,leUserDepartment.getDapartmentId())
                .ne(LeUserDepartment::getId,leUserDepartment.getId())
                .count() > 0) {
            throw new RemoteServiceException("该账号设置过科室");
        }

        leUserDepartment.updateById();
    }

    public void delUser(String id) {
        leUserDepartmentService.removeById(id);
    }

    public LeConfig configDeatil() {
        if (leConfigService.lambdaQuery().eq(LeConfig::getLeConfigId,"1").count() < 1)
            return new LeConfig();

        return leConfigService.getById("1");
    }

    public void addConfig(LeConfig leConfig) {
        if (leConfigService.lambdaQuery().eq(LeConfig::getLeConfigId,"1").count() < 1) {
            leConfig.setLeConfigId("1");
            leConfig.insert();
        }

        leConfig.setLeConfigId("1");
        leConfig.updateById();
    }

    public void importUser(List<Object> objects) {

        List<LeUserDepartment> leUserDepartments = new ArrayList<>();

        for (Object o : objects) {
            List<Object> row = (List<Object>) o;
            List<AdminUser> adminUsers = adminUserService.lambdaQuery().eq(AdminUser::getUserName, (String) row.get(0)).list();

            if (CollectionUtils.isEmpty(adminUsers))
                throw new RemoteServiceException((String) row.get(0)+"未找到当前账号");

            AdminWebsit adminWebsit = adminWebsitService.getById((String) row.get(1));

            if (adminWebsit == null)
                throw new RemoteServiceException((String) row.get(1)+"未找到当前网点");

            List<LeDepartment> leDepartments = leDepartmentService.lambdaQuery().eq(LeDepartment::getDapartment, (String) row.get(2)).list();

            if (CollectionUtils.isEmpty(leDepartments))
                throw new RemoteServiceException((String) row.get(2)+"未找到当前科室");

            AdminUser adminUser = adminUsers.get(0);

            LeDepartment leDepartment = leDepartments.get(0);

            LeUserDepartment leUserDepartment = new LeUserDepartment();

            leUserDepartment.setAdminUserId(adminUser.getAdminUserId());
            leUserDepartment.setNickName(adminUser.getNickName());
            leUserDepartment.setUserName(adminUser.getUserName());
            leUserDepartment.setDapartment(leDepartment.getDapartment());
            leUserDepartment.setDapartmentId(leDepartment.getId());
            leUserDepartment.setWebsitId(adminWebsit.getWebsitId());
            leUserDepartment.setWebsitName(adminWebsit.getName());
            leUserDepartment.setCompanyWechatId(adminWebsit.getCompanyWechatId());
            leUserDepartment.setCompanyWechatName(adminWebsit.getCompanyWechatName());


            leUserDepartments.add(leUserDepartment);
        }

        leUserDepartmentService.saveBatch(leUserDepartments);
    }

    public IPage<LeProjectVO> listProject(Page page, ZfireParamBean zfireParam) {

        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, LeProjectVO.class, adminUser);

        IPage<LeProjectVO> leProjectVOIPage = letterMapper.listProject(page, zfireParam, adminCompanyIds);
        return leProjectVOIPage;
    }

    public LeProject detailProject(String id) {
        LeProject leProject = leProjectService.getById(id);
        return leProject;
    }

    public void addProject(LeProject leProject) {
        leProject.insert();
    }

    public void updateProject(LeProject leProject) {
        leProject.updateById();
    }

    public void delProject(String id) {
        leProjectService.removeById(id);
    }

    public IPage<LeLetterVO> listLetter(Page page, ZfireParamBean zfireParam) {
        //获取当前登录企业id
        AdminUserCom adminUser = commonLogic.getAdminUser();

        List<String> adminCompanyIds = adminUser.getCompanyWechatIds();
        //1.组装查询条件
        zfireParam = FieldUtils.supplyParam(zfireParam, LeLetterVO.class, adminUser);

        IPage<LeLetterVO> leLetterVOIPage = letterMapper.listLetter(page, zfireParam, adminCompanyIds);
        return leLetterVOIPage;

    }

    public LeLetter detailLetter(String id) {
        LeLetter leLetter = leLetterService.getById(id);

        return leLetter;
    }

    public void addLetter(LeLetter leLetter) {
        leLetter.insert();
    }

    public void updateLetter(LeDepartment leDepartment) {
    }

    public void delLetter(String id) {
    }
}
